@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -34,7 +34,7 @@ class LIBSIEVEEDITOR_EXPORT ImportImapSettingWizard : public KAssistantDialog
     Q_OBJECT
 public:
     explicit ImportImapSettingWizard(QWidget *parent = nullptr);
-    ~ImportImapSettingWizard();
+    ~ImportImapSettingWizard() override;
 
     void next() override;
 
