@@ -18,12 +18,14 @@
 */
 
 #include "sieveeditormainwindow.h"
+
 #include "sieveeditormainwidget.h"
 #include "sieveeditorconfiguredialog.h"
 #include "serversievesettingsdialog.h"
 #include "sieveserversettings.h"
 #include "sieveeditorcentralwidget.h"
 #include "sieveeditorglobalconfig.h"
+#include "sievepurposemenuwidget.h"
 #include "sieveeditorbookmarks.h"
 #include "importwizard/importimapsettingwizard.h"
 #include "PimCommon/KActionMenuChangeCase"
@@ -31,6 +33,7 @@
 #include <KSharedConfig>
 #include <KIconEngine>
 #include <KIconLoader>
+#include <KMessageBox>
 #include <PimCommon/NetworkManager>
 
 #include <KLocalizedString>
@@ -45,6 +48,7 @@
 #include <QLabel>
 #include <QCloseEvent>
 #include <QNetworkConfigurationManager>
+#include <QTemporaryFile>
 
 SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
     : KXmlGuiWindow(parent)
@@ -181,12 +185,23 @@ void SieveEditorMainWindow::setupActions()
     ac->addAction(QStringLiteral("import_script"), mImportAction);
     mImportAction->setEnabled(false);
 
-    mShareAction = new QAction(i18n("Share..."), this);
-    connect(mShareAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotShareScript);
-    ac->addAction(QStringLiteral("share_script"), mShareAction);
+    SievePurposeMenuWidget *purposeMenu = new SievePurposeMenuWidget(this, this);
+    if (purposeMenu->menu()) {
+        mShareAction = new QAction(i18n("Share..."), this);
+        ac->addAction(QStringLiteral("share_script"), mShareAction);
+        mShareAction->setMenu(purposeMenu->menu());
+        mShareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+        purposeMenu->setEditorWidget(mMainWidget->sieveEditorMainWidget());
+    } else {
+        delete purposeMenu;
+    }
+
+    mShareHotNewStuffAction = new QAction(i18n("Share Script..."), this);
+    connect(mShareHotNewStuffAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotShareScript);
+    ac->addAction(QStringLiteral("share_hot_new_stuff_script"), mShareHotNewStuffAction);
     const QStringList overlays = QStringList() << QStringLiteral("list-add");
-    mShareAction->setIcon(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)));
-    mShareAction->setEnabled(false);
+    mShareHotNewStuffAction->setIcon(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)));
+    mShareHotNewStuffAction->setEnabled(false);
 
     mSpellCheckAction = new QAction(i18n("Check Spelling..."), this);
     connect(mSpellCheckAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotCheckSpelling);
@@ -214,20 +229,14 @@ void SieveEditorMainWindow::setupActions()
     ac->addAction(QStringLiteral("uncomment_code"), mUncommentAction);
     ac->setDefaultShortcut(mUncommentAction, Qt::CTRL + Qt::SHIFT + Qt::Key_D);
 
-    mZoomInAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-in")), i18n("&Zoom In"), this);
+    mZoomInAction = KStandardAction::zoomIn(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotZoomIn, this);
     ac->addAction(QStringLiteral("zoom_in"), mZoomInAction);
-    connect(mZoomInAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotZoomIn);
-    ac->setDefaultShortcut(mZoomInAction, QKeySequence(Qt::CTRL + Qt::Key_Plus));
 
-    mZoomOutAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18n("Zoom &Out"), this);
+    mZoomOutAction = KStandardAction::zoomOut(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotZoomOut, this);
     ac->addAction(QStringLiteral("zoom_out"), mZoomOutAction);
-    connect(mZoomOutAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotZoomOut);
-    ac->setDefaultShortcut(mZoomOutAction, QKeySequence(Qt::CTRL + Qt::Key_Minus));
 
-    mZoomResetAction = new QAction(i18nc("Reset the zoom", "Reset"), this);
-    connect(mZoomResetAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotZoomReset);
+    mZoomResetAction = KStandardAction::actualSize(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotZoomReset, this);
     ac->addAction(QStringLiteral("zoom_reset"), mZoomResetAction);
-    ac->setDefaultShortcut(mZoomResetAction, QKeySequence(Qt::CTRL + Qt::Key_0));
 
     mMenuChangeCaseAction = new PimCommon::KActionMenuChangeCase(this);
     ac->addAction(QStringLiteral("change_case_menu"), mMenuChangeCaseAction);
@@ -302,6 +311,11 @@ void SieveEditorMainWindow::slotDeleteScript()
     mMainWidget->sieveEditorMainWidget()->deleteScript();
 }
 
+QString SieveEditorMainWindow::currentText() const
+{
+    return mMainWidget->sieveEditorMainWidget()->currentText();
+}
+
 void SieveEditorMainWindow::closeEvent(QCloseEvent *e)
 {
     if (mMainWidget->sieveEditorMainWidget()->needToSaveScript()) {
@@ -356,6 +370,7 @@ void SieveEditorMainWindow::slotUpdateActions()
     mSaveAsAction->setEnabled(hasPage);
     mImportAction->setEnabled(hasPage);
     mShareAction->setEnabled(hasPage && !mNetworkIsDown);
+    mShareHotNewStuffAction->setEnabled(hasPage && !mNetworkIsDown);
     mSpellCheckAction->setEnabled(editActionEnabled);
     mCheckSyntaxAction->setEnabled(editActionEnabled && !mNetworkIsDown);
     mCreateRulesGraphicallyAction->setEnabled(editActionEnabled);
