@@ -161,12 +161,12 @@ void SieveEditorPageWidget::slotPutResult(KManageSieve::SieveJob *job, bool succ
     } else {
         const QString msg = job->errorString();
         if (!msg.isEmpty()) {
-            KMessageBox::error(nullptr,
+            KMessageBox::error(this,
                                i18n("Uploading the Sieve script failed.\n"
                                     "The server responded:\n%1", msg),
                                i18n("Sieve Error"));
         } else {
-            KMessageBox::error(nullptr,
+            KMessageBox::error(this,
                                i18n("Uploading the Sieve script failed.\n"
                                     "unknown reason\n"),
                                i18n("Sieve Error"));
@@ -349,6 +349,11 @@ void SieveEditorPageWidget::zoomOut()
     mSieveEditorWidget->zoomOut();
 }
 
+QString SieveEditorPageWidget::currentText() const
+{
+    return mSieveEditorWidget->script();
+}
+
 void SieveEditorPageWidget::wordWrap(bool state)
 {
     mSieveEditorWidget->wordWrap(state);
